@@ -10,7 +10,7 @@ async fn main() -> Result<()> {
     let device_name = std::env::var("DEVICE_NAME")?;
     let product_secret = std::env::var("PRODUCT_SECRET")?;
 
-    let reg = DynamicRegister::new_public_tls(&host, &product_key, &product_secret, &device_name)?;
+    let reg = DynamicRegister::new_tls(&host, &product_key, &product_secret, &device_name)?;
     let res = reg.register().await?;
     info!("{:?}", res);
 
